pub enum Stcc4Error<E> {
ReadI2cError(E),
WriteI2cError(E),
InvalidState,
InvalidData,
CrcError(CrcError),
}Expand description
Represents any error that may happen during communication.
Variants
ReadI2cError(E)
An error occurred while reading from the sensor.
WriteI2cError(E)
An error occurred while writing to the sensor.
InvalidState
The sensor is in a state that does not permit this command.
InvalidData
The sensor returned data which could not be parsed.
CrcError(CrcError)
CRC related error.